@@ -55,10 +55,12 @@ pub fn lex(source: &str) -> Vec<Token>{
                     Err(e) => push_str(&mut tokens, e.content),
                 }
             },
-            '>' => {
+            '>' if (tokens.last() == Some(&Token::Newline) || tokens.len() == 0) => {
                 let token = lex_blockquotes(&mut char_iter);
                 match token {
-                    Ok(t) => tokens.push(t),
+                    Ok(t) => {
+                        tokens.push(t);
+                        },
                     Err(e) => push_str(&mut tokens, e.content),
                 }
             },
@@ -77,7 +79,7 @@ pub fn lex(source: &str) -> Vec<Token>{
                 }
             },
             '<' => {
-                let token = lex_easy_links(&mut char_iter);
+                let token = lex_side_carrot(&mut char_iter);
                 match token {
                     Ok(t) => tokens.push(t),
                     Err(e) => push_str(&mut tokens, e.content),
@@ -137,15 +139,12 @@ pub fn parse(tokens: Vec<Token>) -> String {
         }
         if quote_level > 0 {
             match token {
-                Token::BlockQuote(l, _s) => {
-                    while l < &quote_level {
-                        html.push_str(format!("</blockquote>").as_str());
-                        quote_level-=1;
-                    }
-                },
+                Token::BlockQuote(_l, _s) => {},
+                Token::Newline => {},
                 _ => {
                     for _i in 0..quote_level {
                         html.push_str(format!("</blockquote>").as_str());
+                        quote_level-=1;
                     }
                 }
             }
@@ -161,10 +160,10 @@ pub fn parse(tokens: Vec<Token>) -> String {
                 html.push_str(format!("{}", remove_tags(t)).as_str())
             },
             Token::Header(l, t, lbl) => {
-                let mut id = String::new();
+                let mut id;
                 match lbl {
-                    Some(_t) => id = lbl.as_ref().unwrap().clone(),
-                    None => id = t.clone(),
+                    Some(_t) => id = lbl.as_ref().unwrap().to_string(),
+                    None => id = t.to_string(),
                 };
                 id.make_ascii_lowercase();
                 html.push_str(format!("<h{level} id=\"{id}\">{text}</h{level}>\n", 
@@ -187,6 +186,7 @@ pub fn parse(tokens: Vec<Token>) -> String {
                 }
                 html.push_str(format!("<li>{}</li>", remove_tags(t)).as_str())
             },
+            Token::Newline => {html.push('\n')},
             Token::ParagraphBreak => {
                 if in_paragraph {
                     html.push_str(format!("</p>").as_str());
@@ -210,6 +210,10 @@ pub fn parse(tokens: Vec<Token>) -> String {
                 ).as_str())
             },
             Token::BlockQuote(l, t) => {
+                if in_paragraph {
+                    html.push_str(format!("</p>").as_str());
+                    in_paragraph = false;
+                }
                 match quote_level {
                     _ if l == &quote_level => {},
                     _ if l < &quote_level => {
@@ -229,7 +233,7 @@ pub fn parse(tokens: Vec<Token>) -> String {
                     _ => {},
                 }
                 if !t.is_empty(){
-                    html.push_str(format!("<p>{}</p>", remove_tags(t)).as_str());
+                    html.push_str(format!("{}", remove_tags(t)).as_str());
                 }
             },
             Token::Image(l, t) => html.push_str(format!("<img src=\"{link}\" alt=\"{text}\"", link=l, text=remove_tags(t)).as_str()),
