@@ -1,5 +1,5 @@
 use mini_markdown::render;
-use mini_markdown::lex;
+// use mini_markdown::lex;
 
 
 #[test]
@@ -29,10 +29,10 @@ fn test_moderate_render(){
         ("Text attributes _italic_, \n**bold**, `monospace`. Some implementations may use *single-asterisks* for italic text.",
         "<p>Text attributes <em>italic</em>, \n<strong>bold</strong>, <code>monospace</code>. Some implementations may use <em>single-asterisks</em> for italic text.</p>"),
         ("Horizontal rule:\n\n---\n\nStrikethrough:\n\n~~strikethrough~~\n\n",
-        "<p>Horizontal rule:</p><hr /><p>Strikethrough:</p><strike>strikethrough</strike>"
+        "<p>Horizontal rule:\n<hr />\nStrikethrough:\n<strike>strikethrough</strike>\n</p>"
         ),
-        ("> Outer quote with some text.\n> \n>> Inner quote with some other text",
-        "<blockquote><p>Outer quote with some text.</p><blockquote><p>Inner quote with some other text</p></blockquote></blockquote>"
+        ("> Outer quote with some text 1.\n> \n>> Inner quote with some other text\n> Outer again",
+        "<blockquote>Outer quote with some text 1.\n\n<blockquote>Inner quote with some other text\n</blockquote>Outer again</blockquote>"
         ),
         ("```\nCode block 1\n```",
         "<div class=\"language-plaintext highlighter-rouge\"><div class=\"highlight\"><pre class=\"highlight\"><code>Code block 1\n</code></pre></div></div>"
@@ -43,8 +43,17 @@ fn test_moderate_render(){
         ("```\nMulti\nLine\nCode block\n```",
         "<div class=\"language-plaintext highlighter-rouge\"><div class=\"highlight\"><pre class=\"highlight\"><code>Multi\nLine\nCode block\n</code></pre></div></div>"
         ),
-        ("> Outer quote with some text.\n> \n>> Inner quote with some other text",
-        "<blockquote><p>Outer quote with some text.</p><blockquote><p>Inner quote with some other text</p></blockquote></blockquote>"
+        ("> Outer quote with some text.\nNon-quoted text\n> Quote with some other text",
+        "<blockquote>Outer quote with some text.\n</blockquote><p>Non-quoted text\n</p><blockquote>Quote with some other text</blockquote>"
+        ),
+        ("> Outer quote with some text.\nNon-quoted text\nMore non-quoted\n> Quote with some other text",
+        "<blockquote>Outer quote with some text.\n</blockquote><p>Non-quoted text\nMore non-quoted\n</p><blockquote>Quote with some other text</blockquote>"
+        ),
+        ("Don't -> quote",
+        "<p>Don't -> quote</p>"
+        ),
+        ("Don't -> quote\n> Do Quote\nDon't quote this either",
+        "<p>Don't -> quote\n</p><blockquote>Do Quote\n</blockquote><p>Don't quote this either</p>"
         ),
         ("Testing an inline link [Link title](http://google.com)",
         "<p>Testing an inline link <a href=\"http://google.com\">Link title</a></p>"
@@ -56,11 +65,12 @@ fn test_moderate_render(){
 
     for test in tests.iter(){
         let html = render(test.0);
+        // println!("lex: {:?}", lex(test.0));
         assert_eq!(html, test.1);
     }
 }
 
-use std::fs;
+// use std::fs;
 
 #[test]
 fn test_full_render(){
